@@ -1,12 +1,19 @@
 # -*- coding: utf-8 -*-
 """
-Created on Fri Jul 22 14:26:12 2022
-
 @author: franc
 """
 
-import pyodbc
-import mariadb as mdb
+try:
+    import pyodbc
+except:
+    print("pyodbc not found")
+
+try:
+    import mariadb as mdb
+except:
+    print("mariadb not found")
+    
+import sqlite3
 import pandas as pd
 from datetime import datetime
 import numpy as np
@@ -24,12 +31,13 @@ class dbhandler:
         self.dbtype = dbtype
         
         self.cur = self.conn.cursor()
-        
-        try: 
-            self.cur.execute("USE rapidb ;")
-        except:
-            self.cur.execute("CREATE DATABASE rapidb ;")
-            self.cur.execute("USE rapidb ;")
+
+        if self.dbtype in ["mssql","mariadb"]:   
+            try: 
+                self.cur.execute("USE rapidb ;")
+            except:
+                self.cur.execute("CREATE DATABASE rapidb ;")
+                self.cur.execute("USE rapidb ;")
         
         self.table_memory = []
         
@@ -50,7 +58,7 @@ class dbhandler:
                                             date_time DATETIME DEFAULT CURRENT_TIMESTAMP
                                         );    
                                     """)
-                elif self.dbtype == "mariadb":
+                elif self.dbtype in ["mariadb"]:
                     self.cur.execute(f"""
                                         CREATE TABLE IF NOT EXISTS {table_name}
                                         (
@@ -58,6 +66,16 @@ class dbhandler:
                                             date_time DATETIME(6) DEFAULT CURRENT_TIMESTAMP
                                         );    
                                     """)
+                elif self.dbtype in ["sqlite"]:
+                    self.cur.execute(f"""
+                                        CREATE TABLE IF NOT EXISTS {table_name}
+                                        (
+                                            id INTEGER PRIMARY KEY,
+                                            date_time DATETIME(6) DEFAULT CURRENT_TIMESTAMP
+                                        );    
+                                    """)
+                    self.conn.commit()
+                                    
             except:
                 0
         
@@ -66,7 +84,7 @@ class dbhandler:
             query_part1 = f" INSERT INTO {table_name} ("
             query_part2 = """ VALUES ( """
             
-        elif(self.dbtype == "mariadb"):
+        elif(self.dbtype in ["mariadb","sqlite"]):
             query_part1 = f" INSERT INTO {table_name} (date_time,"
             query_part2 = f""" VALUES ("{datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")}","""    
             
@@ -88,6 +106,8 @@ class dbhandler:
         
         try:
             self.cur.execute(query_total)
+            if self.dbtype == "sqlite":
+                self.conn.commit()
             
         except:
             
@@ -98,10 +118,16 @@ class dbhandler:
                                     WHERE TABLE_NAME = N'{table_name}'""")
                 all_columns = self.cur.fetchall()
                 all_columns = list(np.array(all_columns).flatten())
-            elif(self.dbtype == "mariadb"):
+            elif(self.dbtype in ["mariadb"]):
                 self.cur.execute(f"SHOW COLUMNS FROM {table_name}")
                 all_columns = self.cur.fetchall()
                 all_columns = list(np.array(all_columns)[:,0])
+            elif(self.dbtype in ["sqlite"]):
+                self.cur.execute(f"PRAGMA table_info({table_name});")
+                all_columns_fetch = self.cur.fetchall()
+                all_columns = []
+                for c in all_columns_fetch:
+                    all_columns.append(c[1])
                 
             # Add missing columns
             for key in all_keys:
@@ -111,17 +137,19 @@ class dbhandler:
                     if( isinstance(values[key],str) ):
                         typec = "TEXT"
                     elif( isinstance(values[key],float) | isinstance(values[key],int) ):
-                        typec = {"mssql":"FLOAT","mariadb":"DOUBLE"}[self.dbtype]
+                        typec = {"mssql":"FLOAT","mariadb":"DOUBLE","sqlite":"DOUBLE"}[self.dbtype]
                     else:
                         raise "TYPE ERROR"
                     
                     if(self.dbtype == "mssql"):
                         self.cur.execute(f"ALTER TABLE {table_name} ADD {key} {typec}")
-                    elif(self.dbtype == "mariadb"):
+                    elif(self.dbtype in ["mariadb","sqlite"]):
                         self.cur.execute(f"ALTER TABLE {table_name} ADD COLUMN {key} {typec}")
             
             # Call again row insertion
             self.cur.execute(query_total)
+            if self.dbtype == "sqlite":
+                self.conn.commit()
             
                 
     def get_DataFrame(self,table_name,start=None,end=None):
@@ -146,7 +174,11 @@ class dbhandler:
                 dts = dts.replace(" ","T")[:19]
             query = query + f" date_time <= '{dts}' "
             
-        return pd.read_sql(query,self.conn,index_col="id")
+        df = pd.read_sql(query,self.conn,index_col="id")
+        if(self.dbtype == "sqlite"):
+            df["date_time"] = pd.to_datetime(df['date_time'])
+        
+        return df
     
 
 
@@ -195,5 +227,15 @@ class mariadb(dbhandler):
                     )
         
         dbhandler.__init__(self,conn,"mariadb")
+       
         
-        
\ No newline at end of file
+       
+class sqlite(dbhandler):
+    
+    def __init__(self,dbname="rapi.db"):
+        
+        conn = sqlite3.connect(dbname)
+        dbhandler.__init__(self,conn,"sqlite")
+        
+        
+
